==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebSummaryOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryOperandDescription } from "./WebSummaryOperandDescription";
/**
 * @hidden
 */
export let WebSummaryOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSummaryOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebSummaryOperandDescriptionMetadata.a == null) {
                WebSummaryOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSummaryOperandDescriptionMetadata.c(WebSummaryOperandDescriptionMetadata.a);
            }
            if (a.k(WebSummaryOperandDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebSummaryOperandDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SummaryOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        }
        static d(a) {
            WebSummaryOperandDescriptionMetadata.b(a);
            a.ad("WebSummaryOperand", () => new WebSummaryOperandDescription());
            a.ac("WebSummaryOperand", WebSummaryOperandDescriptionMetadata.a);
        }
    }
    WebSummaryOperandDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSummaryOperandDescriptionMetadata, 'WebSummaryOperandDescriptionMetadata');
    WebSummaryOperandDescriptionMetadata.a = null;
    return WebSummaryOperandDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebSummaryOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryOperandDescription } from "./WebSummaryOperandDescription";
/**
 * @hidden
 */
export let WebSummaryOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSummaryOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebSummaryOperandDescriptionMetadata.a == null) {
                WebSummaryOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSummaryOperandDescriptionMetadata.c(WebSummaryOperandDescriptionMetadata.a);
            }
            if (a.k(WebSummaryOperandDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebSummaryOperandDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SummaryOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebSummaryOperandDescriptionMetadata.b(a);
            a.ae("WebSummaryOperand", () => new WebSummaryOperandDescription());
            a.ad("WebSummaryOperand", WebSummaryOperandDescriptionMetadata.a);
        }
    }
    WebSummaryOperandDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSummaryOperandDescriptionMetadata, 'WebSummaryOperandDescriptionMetadata');
    WebSummaryOperandDescriptionMetadata.a = null;
    return WebSummaryOperandDescriptionMetadata;
})();
